package dockerfile-opam

  1. Overview
  2. Docs

Module Dockerfile_opam.DistroSource

Run Opam commands across a matrix of Docker containers. Each of these containers represents a different version of OCaml, Opam and an OS distribution (such as Debian or Alpine).

Known distributions and OCaml variants

Sourcetype distro = [
  1. | `Alpine of [ `V3_3 | `V3_4 | `V3_5 | `V3_6 | `V3_7 | `V3_8 | `V3_9 | `V3_10 | `V3_11 | `V3_12 | `V3_13 | `V3_14 | `V3_15 | `V3_16 | `V3_17 | `V3_18 | `V3_19 | `V3_20 | `V3_21 | `V3_22 | `V3_23 ]
  2. | `Archlinux of [ `Latest ]
  3. | `CentOS of [ `V6 | `V7 | `V8 | `V9 | `V10 ]
  4. | `Debian of [ `V13 | `V12 | `V11 | `V10 | `V9 | `V8 | `V7 | `Testing | `Unstable ]
  5. | `Fedora of [ `V21 | `V22 | `V23 | `V24 | `V25 | `V26 | `V27 | `V28 | `V29 | `V30 | `V31 | `V32 | `V33 | `V34 | `V35 | `V36 | `V37 | `V38 | `V39 | `V40 | `V41 | `V42 | `V43 ]
  6. | `OracleLinux of [ `V7 | `V8 | `V9 | `V10 ]
  7. | `OpenSUSE of [ `V42_1 | `V42_2 | `V42_3 | `V15_0 | `V15_1 | `V15_2 | `V15_3 | `V15_4 | `V15_5 | `V15_6 | `V16_0 | `Tumbleweed ]
  8. | `Ubuntu of [ `V12_04 | `V14_04 | `V15_04 | `V15_10 | `V16_04 | `V16_10 | `V17_04 | `V17_10 | `V18_04 | `V18_10 | `V19_04 | `V19_10 | `V20_04 | `V20_10 | `V21_04 | `V21_10 | `V22_04 | `V22_10 | `V23_04 | `V23_10 | `V24_04 | `V24_10 | `V25_04 | `V25_10 | `V26_04 ]
  9. | `Cygwin of [ `Ltsc2016 | `Ltsc2019 | `Ltsc2022 | `Ltsc2025 ]
  10. | `Windows of [ `Mingw | `Msvc ] * [ `Ltsc2019 ]
  11. | `WindowsServer of [ `Mingw | `Msvc ] * [ `Ltsc2022 | `Ltsc2025 ]
]
Sourceval sexp_of_distro : distro -> Sexplib0.Sexp.t
Sourceval distro_of_sexp : Sexplib0.Sexp.t -> distro
Sourceval __distro_of_sexp__ : Sexplib0.Sexp.t -> distro
Sourcetype t = [
  1. | `Alpine of [ `V3_3 | `V3_4 | `V3_5 | `V3_6 | `V3_7 | `V3_8 | `V3_9 | `V3_10 | `V3_11 | `V3_12 | `V3_13 | `V3_14 | `V3_15 | `V3_16 | `V3_17 | `V3_18 | `V3_19 | `V3_20 | `V3_21 | `V3_22 | `V3_23 | `Latest ]
  2. | `Archlinux of [ `Latest ]
  3. | `CentOS of [ `V6 | `V7 | `V8 | `V9 | `V10 | `Latest ]
  4. | `Debian of [ `V13 | `V12 | `V11 | `V10 | `V9 | `V8 | `V7 | `Stable | `Testing | `Unstable ]
  5. | `Fedora of [ `V21 | `V22 | `V23 | `V24 | `V25 | `V26 | `V27 | `V28 | `V29 | `V30 | `V31 | `V32 | `V33 | `V34 | `V35 | `V36 | `V37 | `V38 | `V39 | `V40 | `V41 | `V42 | `V43 | `Latest ]
  6. | `OracleLinux of [ `V7 | `V8 | `V9 | `V10 | `Latest ]
  7. | `OpenSUSE of [ `V42_1 | `V42_2 | `V42_3 | `V15_0 | `V15_1 | `V15_2 | `V15_3 | `V15_4 | `V15_5 | `V15_6 | `V16_0 | `Tumbleweed | `Latest ]
  8. | `Ubuntu of [ `V12_04 | `V14_04 | `V15_04 | `V15_10 | `V16_04 | `V16_10 | `V17_04 | `V17_10 | `V18_04 | `V18_10 | `V19_04 | `V19_10 | `V20_04 | `V20_10 | `V21_04 | `V21_10 | `V22_04 | `V22_10 | `V23_04 | `V23_10 | `V24_04 | `V24_10 | `V25_04 | `V25_10 | `V26_04 | `Latest | `LTS ]
  9. | `Cygwin of [ `Ltsc2016 | `Ltsc2019 | `Ltsc2022 | `Ltsc2025 | `Latest ]
  10. | `Windows of [ `Mingw | `Msvc ] * [ `Ltsc2019 | `Latest ]
  11. | `WindowsServer of [ `Mingw | `Msvc ] * [ `Ltsc2022 | `Ltsc2025 | `Latest ]
]
Sourceval sexp_of_t : t -> Sexplib0.Sexp.t
Sourceval t_of_sexp : Sexplib0.Sexp.t -> t
Sourceval __t_of_sexp__ : Sexplib0.Sexp.t -> t
Sourcetype os_family = [
  1. | `Cygwin
  2. | `Linux
  3. | `Windows
]

The operating system family a distro belongs to.

Sourceval sexp_of_os_family : os_family -> Sexplib0.Sexp.t
Sourceval os_family_of_sexp : Sexplib0.Sexp.t -> os_family
Sourceval __os_family_of_sexp__ : Sexplib0.Sexp.t -> os_family
Sourceval os_family_of_distro : t -> os_family

os_family_of_distro t returns the OS family of the distro.

Sourceval os_family_to_string : os_family -> string

os_family_to_string os returns a string representing the OS family.

Sourceval opam_repository : os_family -> string

opam_repository os_family returns the git URL to the default Opam repository.

Sourceval personality : os_family -> Ocaml_version.arch -> string option

personality os_family arch returns the personality associated to the architecture, if os_family is `Linux.

Sourceval is_same_distro : t -> t -> bool

is_same_distro d1 d2 returns whether d1 is the same distro as d2, regardless of their respective versions.

Sourceval compare : t -> t -> int

compare a b is a comparison function for t. The ordering is only total for distro values and is lexicographic by distribution name and sorted by version order within each distribution.

Sourceval resolve_alias : t -> distro

resolve_alias t will resolve t into a concrete version. This removes versions such as Latest.

Sourceval distros : t list

Enumeration of the supported Docker container distributions.

Sourceval latest_distros : t list

Enumeration of the latest stable (ideally LTS) supported distributions.

Sourceval master_distro : t

The distribution that is the top-level alias for the latest tag in the ocaml/opam2 Docker Hub build.

Sourceval builtin_ocaml_of_distro : t -> string option

builtin_ocaml_of_distro t will return the OCaml version supplied with the distribution packaging, and None if there is no supported version.

Sourceval human_readable_string_of_distro : t -> string

human_readable_string_of_distro t returns a human readable version of the distribution tag, including version information.

Sourceval human_readable_short_string_of_distro : t -> string

human_readable_short_string_of_distro t returns a human readable short version of the distribution tag, excluding version information.

Sourcetype package_manager = [
  1. | `Apk
    (*

    Alpine Apk

    *)
  2. | `Apt
    (*

    Debian Apt

    *)
  3. | `Yum
    (*

    Fedora Yum

    *)
  4. | `Zypper
    (*

    OpenSUSE Zypper

    *)
  5. | `Pacman
    (*

    Archlinux Pacman

    *)
  6. | `Cygwin
    (*

    Cygwin package manager

    *)
  7. | `Windows
    (*

    Native Windows, WinGet, Cygwin

    *)
]

The package manager used by a distro.

Sourceval sexp_of_package_manager : package_manager -> Sexplib0.Sexp.t
Sourceval package_manager_of_sexp : Sexplib0.Sexp.t -> package_manager
Sourceval __package_manager_of_sexp__ : Sexplib0.Sexp.t -> package_manager
Sourceval package_manager : t -> package_manager

package_manager t returns the package manager used by that distribution. Many derived distributions (such as OracleLinux) share the same package manager from a base distribution (such as CentOS).

Sourceval bubblewrap_version : t -> (int * int * int) option

bubblewrap_version t returns the version of bubblewrap available on that distribution.

Docker Hub addresses

Sourceval tag_of_distro : t -> string

tag_of_distro t convert a distribution t to a Docker Hub tag.

Sourceval distro_of_tag : string -> t option

distro_of_tag s parses s into a t distribution, and None otherwise.

Sourceval latest_tag_of_distro : t -> string

latest_tag_of_distro distro will generate a Docker Hub tag that is a convenient short form for the latest stable release of a particular distribution. This tag will be regularly rewritten to point to any new releases of the distribution.

Sourceval base_distro_tag : ?arch:Ocaml_version.arch -> t -> string * string

base_distro_tag ?arch t will return a tuple of a Docker Hub user/repository and tag for which the base image of a distribution can be found (e.g. opensuse/leap,15.0 which maps to opensuse/leap:15.0 on the Docker Hub). This base image is in turn can be used to generate opam and other OCaml tool Dockerfiles. arch defaults to x86_64 and can vary the base user/repository since some architecture are built elsewhere.

CPU architectures

Sourceval distro_arches : Ocaml_version.t -> t -> Ocaml_version.arch list

distro_arches ov t returns the list of architectures that distribution t is supported on for OCaml compiler version ov

Sourceval distro_supported_on : Ocaml_version.arch -> Ocaml_version.t -> t -> bool

distro_supported_on arch ov distro returns true if the combination of CPU arch, compiler version ov is available on the distribution distro.

Opam build infrastructure support

Sourceval active_distros : Ocaml_version.arch -> t list

active_distros arch returns the list of currently supported distributions in the opam build infrastructure. Distributions that are end-of-life upstream will rotate out of this list regularly.

Sourceval active_tier1_distros : Ocaml_version.arch -> t list

Tier 1 distributions are those supported for the full matrix of compiler versions in the opam build infrastructure. The Docker base images will compile a base image for every OCaml version, so this list should be added to sparingly.

Sourceval active_tier2_distros : Ocaml_version.arch -> t list

Tier 2 distributions are those supported for a limited set of compiler versions in the opam build infrastructure. The distros in this list are also tested for packages in the opam repository.

Sourceval active_tier3_distros : Ocaml_version.arch -> t list

Tier 3 distributions are those supported for a limited set of compiler versions in the opam build infrastructure. While these distros will have base images compiled for them, they are not widely tested. Distros maybe here as they are on the way to being deprecated, or new and still experimental.